! ===========================================================================================================
! integer function read_configtable.f90
!
! -----------------------------------------------------------------------------------------------------------
!
! Revision history
! date     who    what
! 20170712 all    Release of qcplus v1.1 - many changes to all, some documented/tracked, some not
! 20160511 all    Initial release of qcplus v1.1.0
!
! ===========================================================================================================
! User's Manual:
!
! ARGO USER'S MANUAL Version 3.03 20130828 (August 28th 2013)
! ARGO USER'S MANUAL Version 3.1  20141107 (November 7th, 2014)
! 
! QC Manual
! Argo Quality Control Manual Version 2.9.1 20141118 (18 November 2014)

! ===========================================================================================================
! Notes
! Function to read config parameters for netcdf files while passing parameters from qc files
! ===========================================================================================================

integer function read_configtable()

use communication                       ! module
use data_arrays                         ! module
use ncmeta_arrays                       ! module

implicit none

! ===========================================================================================================
! varialbe/array declarations

character(len=168) :: line ! One line read from file
integer, parameter :: CONFIG_FILE_UNIT = 10  ! Handler
integer :: status, ios, lnblnk , idx
integer, parameter :: IO_EOF = -1  ! End of File 
character(len=40) :: one_config_param

integer :: result = 0; ! number of table values read
character(len=16),parameter :: sub = 'read_configtable'
character(len=15),parameter :: typ = 'NCMETA RDTCNFG'

logical :: table_exists;

! ===========================================================================================================
! executable statements

if(DEBUG)then; write(msg,'("==== ",a," BEG ====================")')typ;call wrtdbg(sub,msg); endif

read_configtable=FAILURE;						! Assume failure

! Make sure the tables exist
inquire(file=pathname_config_table,exist=table_exists)
if(.not. table_exists) go to 264;
inquire(file=pathname_config_table_skip,exist=table_exists)
if(.not. table_exists) go to 265;

! Read config table 
inp_open=open_old_file_nf(CONFIG_FILE_UNIT,pathname_config_table,"CONFIG","TABLE");
if(.not. inp_open)then;
    write(msg,'("READ_CONFIGTABLE Failed to open talbe fie: ",a)')trim(pathname_config_table); call wrttrc(sub,msg);
    goto 266
endif
if(DEBUG)then; write(msg,'("NCMETA RDCNFG open file: ",a)')trim(pathname_config_table); call wrtdbg(sub,msg); endif
cnt_config_table_param = 0
read(CONFIG_FILE_UNIT,'(168a)',end=101,err=267,iostat=ios) line
do while (ios==IO_OK)
   cnt_config_table_param = cnt_config_table_param + 1
   qc_config_params_lst(cnt_config_table_param)= line(1:40)
   nc_config_params_lst(cnt_config_table_param)= line(41:168)
   read(CONFIG_FILE_UNIT,'(168a)',end=101,err=267,iostat=ios) line
enddo
101 continue
inp_open=close_file(CONFIG_FILE_UNIT,"TAB","CONFIG_TABLE");
if (ios/=IO_EOF) goto 267 ! if there is any error, XXX needed?

! Read config table skip
inp_open=open_old_file_nf(CONFIG_FILE_UNIT,pathname_config_table_skip,"CONFIG","TABLE_SKIP");
if(.not. inp_open)then;
    write(msg,'("READ_CONFIGTABLE Failed to open talbe fie: ",a)')trim(pathname_config_table_skip); call wrttrc(sub,msg);
    goto 268
endif
cnt_config_table_skip_param = 0
read(CONFIG_FILE_UNIT,'(a)',end=102,err=269,iostat=ios) line
do while (ios==IO_OK)
   cnt_config_table_skip_param = cnt_config_table_skip_param + 1
   read(line(1:40),'(a)') qc_config_skip_lst(cnt_config_table_skip_param)
   read(CONFIG_FILE_UNIT,'(a)',end=102,err=269,iostat=ios) line
enddo
102 continue
inp_open=close_file(CONFIG_FILE_UNIT,"TAB","CONFIG_TABLE_SKIP");
if (ios/=IO_EOF) goto 269 ! if there is any error, XXX needed?

read_configtable=SUCCESS;						! Signal SUCCESS
go to 999; ! Skip to THE_END

264 continue
    write(errmsg(1),'("NON-FATAL ERROR 264 in read_configtable")');
    write(errmsg(2),'("NON-FATAL ERROR 264 The CONFIG_TABLE file does not exist: ",a)')trim(pathname_config_table);
    call error_report(sub,264,2,errmsg); ! read_configtable CONFIG_TABLE file does not exist
    go to 999; ! Skip to THE_END
265 continue
    write(errmsg(1),'("NON-FATAL ERROR 265 in read_configtable")');
    write(errmsg(2),'("NON-FATAL ERROR 265 The CONFIG_TABLE_SKIP file does not exist: ",a)')trim(pathname_config_table_skip);
    call error_report(sub,265,2,errmsg); ! read_configtable CONFIG_TABLE_SKIP file does not exist
    go to 999; ! Skip to THE_END
266 continue
    write(errmsg(1),'("NON-FATAL ERROR 266 in read_configtable")');
    write(errmsg(2),'("NON-FATAL ERROR 266 Error opening the CONFIG_TABLE file: ",a)')trim(pathname_config_table);
    call error_report(sub,266,2,errmsg); ! read_configtable error opening CONFIG_TABLE 
    go to 999; ! Skip to THE_END
267 continue
    write(errmsg(1),'("NON-FATAL ERROR 267 in read_configtable")');
    write(errmsg(2),'("NON-FATAL ERROR 267 Error reading CONFIG_TABLE",a)')trim(pathname_config_table);
    call error_report(sub,267,2,errmsg); ! read_configtable rror reading CONFIG_TABLE
    go to 999; ! Skip to THE_END
268 continue
    write(errmsg(1),'("NON-FATAL ERROR 268 in read_configtable")');
    write(errmsg(1),'("NON-FATAL ERROR 268 Error opening the CONFIG_TABLE_SKIP file: ",a)') trim(pathname_config_table_skip);
    call error_report(sub,268,2,errmsg); ! read_configtable rror opening CONFIG_TABLE_SKIP
    go to 999; ! Skip to THE_END
269 continue
    write(errmsg(1),'("NON-FATAL ERROR 269 in read_configtable")');
    write(errmsg(1),'("NON-FATAL ERROR 269 Error reading CONFIG_TABLE_SKIP file: "a)') trim(pathname_config_table_skip);
    call error_report(sub,269,2,errmsg); ! read_configtable error reading CONFIG_TABLE_SKIP
999 continue ! This is THE_END

if(inp_open) inp_open=close_file(CONFIG_FILE_UNIT,"TAB","CONFIG_TABLE???");

if(DEBUG)then; write(msg,'("NCCNFG Number of cnfg params: ",i4)')cnt_config_table_param; call wrtdbg(sub,msg); endif
if(DEBUG)then; write(msg,'("NCCNFG Number of skip params: ",i4)')cnt_config_table_skip_param; call wrtdbg(sub,msg); endif

if(DEBUG)then; write(msg,'("==== RDTNC META <<<<< Leave ",a," ret= ",i3)')sub,read_configtable;call wrtdbg(sub,msg); endif
if(DEBUG)then; write(msg,'("==== ",a," END ====================")')typ;call wrtdbg(sub,msg); endif

return;
end function read_configtable
