! ===========================================================================================================
! integer function read_sensor_params_table.f90

! -----------------------------------------------------------------------------------------------------------
!
! Revision history
! date     who    what
! 20171107 JN     Initial creation of function t6o read the new sensor_params_table
! 20171107 JN     small change to increase size of sensor_param variable line from 120 to 160

! ===========================================================================================================
 
integer function read_sensor_params_table()

use communication                       ! module
use data_arrays                         ! module
use ncmeta_arrays                       ! module

implicit none

! ===========================================================================================================
! varialbe/array declarations

character(len=168) :: line ! One line read from file
integer,parameter :: META_PARAM_FILE_UNIT = 10  ! Handler 
integer :: status, ios, lnblnk , idx
integer,parameter :: IO_EOF = -1  ! End of File 

integer :: result = 0; ! number of table values read
character(len=16),parameter :: sub = 'read_sensor_params_table'
character(len=15),parameter :: typ = 'NCMETA RDTSNSR'

logical :: table_exists;
 
! ===========================================================================================================
! executable statements

if(DEBUG)then; write(msg,'("==== ",a," BEG ====================")')typ;call wrtdbg(sub,msg); endif

read_sensor_params_table=FAILURE;						! Assume failure
! Make sure the table exists
inquire(file=pathname_sensor_params_table,exist=table_exists)
if(.not. table_exists) go to 281
! read_sensor_params_table model table 
inp_open=open_old_file_nf(META_PARAM_FILE_UNIT,pathname_sensor_params_table,"SENSOR_PARAMS","TABLE");
if(.not. inp_open)then
    write(msg,'("READ_SENSOR_PARAMS_TABLE Failed to open talbe fie: ",a)')trim(pathname_sensor_params_table); call wrttrc(sub,msg);
    goto 282
endif
n_sensor_params_table = 0
read(META_PARAM_FILE_UNIT,'(168a)',end=101,err=283,iostat=ios) line
do while (ios==IO_OK)
   n_sensor_params_table = n_sensor_params_table + 1
   sensor_params_table(n_sensor_params_table) = trim(line(1:160))
   read(META_PARAM_FILE_UNIT,'(168a)',end=101,err=283,iostat=ios) line
enddo
101 continue
if (ios/=IO_EOF) goto 283 ! if there is any error, XXX needed?
close(unit=META_PARAM_FILE_UNIT);

read_sensor_params_table=SUCCESS;					! Report success

go to 999; ! Skip to THE_END
281 continue
    write(errmsg(1),'("NON-FATAL ERROR 261 in read_sensor_params_table")');
    write(errmsg(2),'("NON-FATAL ERROR 261 table file not found: ",a)')trim(pathname_sensor_params_table)
    call error_report(sub,261,2,errmsg); ! read_sensor_params_table table file not found
    go to 999; ! Skip to THE_END
282 continue
    read_sensor_params_table=FAILURE
    write(errmsg(1),'("NON-FATAL ERROR 262 in read_sensor_params_table")');
    write(errmsg(2),'("NON-FATAL ERROR 262 opening the SENSOR_PARAMS_TABLE file")');
    write(errmsg(3),'("NON-FATAL ERROR 262 file: ",a)') trim(pathname_sensor_params_table);
    write(errmsg(4),'("NON-FATAL ERROR 262 desc: TABLE")')
    call error_report(sub,262,4,errmsg); ! read_sensor_params_table error opening table file
    go to 999; ! Skip to THE_END
283 continue
    read_sensor_params_table=FAILURE
    write(errmsg(1),'("NON-FATAL ERROR 263 in read_sensor_params_table")');
    write(errmsg(2),'("NON-FATAL ERROR 263 reading SENSOR_PARAMS_TABLE")');
    write(errmsg(3),'("NON-FATAL ERROR 263 read reported error ios: ",i2)')ios;
    close(unit=META_PARAM_FILE_UNIT); ! read_sensor_params_table error reading table file
    call error_report(sub,263,3,errmsg); ! read_sensor_params_tableerror reading table file
    go to 999; ! Skip to THE_END
    

999 continue ! This is THE_END

if(DEBUG)then; write(msg,'("NCSNSR Number of n_sensor_params_table; call wrtlog(sub,msg")'); endif

if(DEBUG)then; write(msg,'("==== RDTNC META <<<<< Leave ",a," ret= ",i3)')sub,read_sensor_params_table;call wrtdbg(sub,msg); endif
if(DEBUG)then; write(msg,'("==== ",a," END ====================")')typ;call wrtdbg(sub,msg); endif

return;

end function read_sensor_params_table
! ===========================================================================================================
