! ===========================================================================================================
! program remove_oldrecords
!
! Revision history
! date     who    what
! 20160511 VH    Initial release of qcplus qcv1.0
! 20150325 CS,RS Initial development
!
! ===========================================================================================================
! Notes
!
! Revision 2015-03-25 (CS,RS)
!
! Remove records in PHY2GTSFMT_TABLE older than the number of days given
! by  time_delay 
!
! It executes  Fortran program (remove_oldrecords.x) to remove old records
!
! called by RemoveRecordsOlderThanGivenDays.qcplus_func

program remove_oldrecords

integer, parameter ::  INP=30;
integer, parameter ::  OUTP=31;
integer :: ios,ic,j,j0,year,mon,day,time_delay;
integer :: ivalues(8);                              ! year,mon,day,hr,mn.sc,ms
character(len=100) :: old_file, new_file, cline, time_delay_str;

call GETENV('old_file',old_file);
call GETENV('new_file',new_file);
call GETENV('time_delay',time_delay_str);

read(time_delay_str,'(i)') time_delay

!print *, "   old_file:", old_file;
!print *, "   new_file:", new_file;
!print *, "   time_delay:", time_delay;

open(INP,file=old_file,form='formatted',status='old',action='read',iostat=ios);
!print *, "INP iostat=", iostat;

open(OUTP,file=new_file,form='formatted',status='new',recl=1000,iostat=ios);
!print *, "OUTP iostat=", iostat;

! get current date
call date_and_time(VALUES=ivalues);
call juldat(ivalues(3),ivalues(2),ivalues(1),j0);
!print *,"j0 = ",j0," ",ivalues(3),ivalues(2),ivalues(1);
j0=j0 - time_delay;
!print *,"j0 = ",j0;

read(INP,'(a)',iostat=ios) cline;
do while (ios==IO_OK)
   ic=index(cline,"/");
   read(cline(ic-4:ic-1),*) year;
   read(cline(ic+1:ic+2),*) mon;
   read(cline(ic+4:ic+5),*) day;
   call juldat(day,mon,year,j);
!   print *,"j = ",j," ",day,mon,year;
   if (j .ge. j0) write(OUTP,'(a)') trim(cline);
   read(INP,'(a)',iostat=ios) cline;
enddo

close(INP);
close(OUTP);

end

!======================================================================================
!     JULDAT.FOR
!     JULDAT... CONVERTS GREGORIAN CALENDAR DATES TO CORRESPONDING
!               JULIAN DAY NUMBERS.
!     PROGRAMMER... J. MALTAIS
!     DATE      ... NOVEMBER 6,1967
!*
!     Y... MAY BE EXPRESSED AS CENTURY PLUS YEAR WITHIN CENTURY
!          OR MAY BE EXPRESSED AS TWO PLACE INTEGER ('73') FOR THE
!          TWENTIETH CENTURY
!
SUBROUTINE JULDAT(DP,MP,YP,J)
DIMENSION IARR(3)
INTEGER D,Y,C,MO,YR,DP,MP,YP
D=DP
M=MP
Y=YP
    1 IF(Y.LT.100)Y=Y+1900
YR=Y
IF(M.GT.2)GO TO 5
MO=M+9
YR=Y-1
GO TO 10
    5 MO=M-3
   10 C=YR/100
YR=YR-100*C
J=(146097*C)/4+(1461*YR)/4+(153*MO+2)/5+D+1721119
RETURN
ENTRY JULARR(IARR,J)
!     DIMENSION IARR(3)
Y=IARR(1)
M=IARR(2)
D=IARR(3)
GO TO 1
END
