! ===========================================================================================================
! character function write_ncprof.f90
!
! -----------------------------------------------------------------------------------------------------------
!
! Revision history
! date     who    what
! 20180307 VH     Add section to NOT put DOXY into core fles, unless "forced" (env var)
! 20170712 all    Release of qcplus v1.1 - many changes to all, some documented/tracked, some not
! 20160511 all    Initial release of qcplus v1.1.0
!
! ===========================================================================================================
! Notes:
!
! This function creates the nc prof file.
! ===========================================================================================================
! Function returns 'y' for successful file creation, "F" for failure
! ===========================================================================================================

character function write_ncprof(ncprof)

use communication                       ! module
use data_arrays                         ! module
use netcdf_arrays			! module
use ncprof_arrays			! module  


implicit none

! ===========================================================================================================
! varialbe/array declarations

character(len=128) , intent( in ) :: ncprof

integer :: ncid;

character(len=12),parameter :: sub = 'write_ncprof'
character(len=4),parameter :: nctype = 'prof'
character(len=5),parameter :: ncjob = 'WRITE'; character(len=4) :: nctup;  ! What job are we doing, nctupe_uppercase
integer :: ret = 0;
! ===========================================================================================================
! executable statements

! Which file is being written, and wat is the filmsg index?
filmsg(l:l) = 'R'; call wrtflm(sub,'Initialize to Running')

call set_uppercase(nctype,nctup)
gloc = 1000; ! gloc - global location of the nc call
gnctype = nctype; ! For calls to cke

if(DEBUG)then; call dbg_ncbeg(sub,nctup,ncjob); endif


! 'N_PROF',                  N_PROF_len
! 'N_PARAM',                 N_PARAM_len
! 'N_LEVELS',                N_LEVELS_len
! 'N_CALIB',                 N_CALIB_len
! 'N_HISTORY',               N_HISTORY_len_prof            ! UNLIMITED for ncprof


! Do we need DOXY?
if(.not. outRDOXY)then
    write(msg,'("DBG DOXY Tunr off DOXY for the output R file")'); call wrtlog(sub,msg);
    hasNCPAR(5) = .false.
endif
ret=create_ncfile(sub,nctype,ncprof,ncid); ! This also defines the dimensins & global vars
write(msg,'("write NCPROF: ",a)')trim(ncprof); call wrtstd(sub,msg); ! STD

write(msg,'(a,"output file opened: ",a)')WRTFILE,trim(ncprof); call wrttrc(sub,msg);

if(DBLEV==62)then; write(DBG,3001)WRTFILE; call close_ncfile(sub,ncid); call direct_exit(sub,0,'LEV62'); endif
3001 format("LEV=62 Exit after nc file creation for ",a);

call def_common_vars(sub,nctype,ncid);

call def_ncprof_vars(sub,ncid);

call def_ncprof_params(sub,ncid);

! NOTEST if(DEBUG) go to 10; if(.not. DEBUG) go to 10; ! Skip to the close

call def_ncprof_calhis(sub,ncid);

call end_define_mode(sub,ncid);

call put_common_data(sub,nctype,ncid);

call put_ncprof_vars(sub,ncid);

call put_ncprof_params(sub,ncid);

call put_ncprof_calhis(sub,ncid);

10 continue; ! Skip to the close

call close_ncfile(sub,ncid);

! See if an error occurred in an array module
if(filmsg(l:l) == 'R')then;
    filmsg(l:l) = 'y'; call wrtflm(sub,'Normal exit, return y for SUCCESS');
elseif((filmsg(l:l) == 'f') .or. (filmsg(l:l) == 'F'))then
    write(msg,'(a,a1,x,a8,x,a)')HEDF,'R',filmsg,'ERROR exit, return F or f'; call wrtlog(sub,msg);
else
    write(msg,'(a,a1,x,a8,x,a)')HEDF,filmsg(l:l),'W Non-standard file result'; call wrtlog(sub,msg);
endif

write(msg,'(a," output file closed: ",a)')WRTFILE,trim(ncprof); call wrtlog(sub,msg);

write_ncprof = filmsg(l:l)

if(DEBUG)then; call dbg_ncret(sub,nctup,ncjob,write_ncprof); endif
if(DEBUG)then; call dbg_ncend(sub,nctup,ncjob); endif

return          ! Normal return
! ===========================================================================================================
end function write_ncprof
! ===========================================================================================================
